#[repr(u8)]pub enum Plfs {
MATCH_EXACT = 0,
MATCH_GTE = 1,
MATCH_LTE = 2,
MATCH_RANGE = 3,
}Variants
MATCH_EXACT = 0
Match payload contents to an exact target value
MATCH_GTE = 1
Match a payload value greater than or equal to a specified target value
MATCH_LTE = 2
Match a payload value smaller than or equal to a specified target value
MATCH_RANGE = 3
Match upon a payload value within a range of values, inclusive
Implementations